package biggests.tables;

import java.awt.*;

import javax.swing.*;
import javax.swing.table.*;

import biggests.utils.*;

/**
 * <p>Title: <code>TableSorterVerticalHeader</code> model</p>
 *
 * <p>Description: This table model implements table sorting and also a table
 *                 header model which writes vertical oriented column names.</p>
 *
 * <p>Copyright:   Copyright (C) 2007  Joana Gonçalves
 *                 This program is free software; you can redistribute
 *                 it and/or modify it under the terms of the GNU General
 *                 Public License as published by the Free Software
 *                 Foundation; either version 3 of the License, or
 *                 any later version.
 *
 *                 This program is distributed in the hope that it will
 *                 be useful, but WITHOUT ANY WARRANTY; without even the
 *                 implied warranty of MERCHANTABILITY or FITNESS FOR A
 *                 PARTICULAR PURPOSE.  See the
 *                 <a href="http://www.gnu.org/licenses/gpl.html">
 *                 GNU General Public License</a> for more details.
 * </p>
 *
 * @author Joana Gonçalves
 */
public class TableSorterVerticalHeader extends TableSorterValues {
    /**
     * Constructs a new <code>ColorsTableSorter</code> model. This model
     * implements table sorting and a table header which writes vertical
     * oriented column names.<br/>
     *
     * @see TableSorterValues#TableSorterValues()
     */
    public TableSorterVerticalHeader() {
        super();
    }

    /**
     * Constructs a new <code>TableSorterVerticalHeader</code> model from a
     * plain table model. This model implements table sorting and a table
     * header which writes vertical oriented column names.
     *
     * @param tableModel        the <code>TableModel</code> which is the basic
     *                          data model for the table
     * @see TableSorterValues#TableSorterValues(TableModel tableModel)
     */
    public TableSorterVerticalHeader(TableModel tableModel) {
        super(tableModel);
    }

    /**
     * Constructs a new <code>TableSorterVerticalHeader</code> model from a plain table
     * model and a given table header. This model implements table sorting and
     * a table header which writes vertical oriented column names.
     *
     * @param tableModel        the <code>TableModel</code> which is the basic
     *                          data model for the table
     * @param tableHeader       the <code>TableHeader</code> which is the
     *                          header for the table
     * @see TableSorterValues#TableSorterValues(TableModel tableModel, TableHeader tableHeader)
     */
    public TableSorterVerticalHeader(TableModel tableModel,
                                     TableHeader tableHeader) {
        super(tableModel, tableHeader);
    }

    public void setTableHeader(JTableHeader tableHeader) {
        if (this.tableHeader != null) {
            this.tableHeader.removeMouseListener(mouseListener);
            TableCellRenderer defaultRenderer = this.tableHeader.
                                                getDefaultRenderer();
            if (defaultRenderer instanceof VerticalSortableHeaderRenderer) {
                this.tableHeader.setDefaultRenderer(((
                        VerticalSortableHeaderRenderer) defaultRenderer).
                        tableCellRenderer);
            }
        }
        this.tableHeader = tableHeader;
        if (this.tableHeader != null) {
            this.tableHeader.addMouseListener(mouseListener);
            this.tableHeader.setDefaultRenderer(
                    new VerticalSortableHeaderRenderer(this.tableHeader.
                    getDefaultRenderer()));
        }
    }

    /**
     * <p>Title: </p>
     *
     * <p>Description: </p>
     *
     * <p>Copyright: Copyright (c) 2006</p>
     *
     * <p>Company: </p>
     *
     * @author Joana P. Gon�alves
     */
    private class VerticalSortableHeaderRenderer implements TableCellRenderer {
        private TableCellRenderer tableCellRenderer;

        public VerticalSortableHeaderRenderer(TableCellRenderer
                                              tableCellRenderer) {
            this.tableCellRenderer = tableCellRenderer;
        }

        public Component getTableCellRendererComponent(JTable table,
                Object value,
                boolean isSelected,
                boolean hasFocus,
                int row,
                int column) {
            Component columnHeaderComponent =
                    tableCellRenderer.getTableCellRendererComponent(table,
                    value, isSelected, hasFocus, row, column);
            JLabel columnHeaderLabel;
            if (columnHeaderComponent instanceof JLabel) {
                columnHeaderLabel = (JLabel) columnHeaderComponent;
                if (column == 0) {
                    columnHeaderLabel.setLayout(new BorderLayout());
                    columnHeaderLabel.setHorizontalTextPosition(JLabel.LEFT);
                    columnHeaderLabel.setVerticalAlignment(JLabel.BOTTOM);
                    int modelColumn = table.convertColumnIndexToModel(column);
                    columnHeaderLabel.setIcon(getHeaderRendererIcon(
                            modelColumn, columnHeaderLabel.getFont().getSize()));
                    return columnHeaderComponent;
                }

                columnHeaderLabel.setLayout(new BorderLayout(0, 3));
/*                columnHeaderLabel.setIcon(new VerticalTextIcon(
                        columnHeaderLabel,
                        columnHeaderLabel.getText(),
                        VerticalTextIcon.ROTATE_LEFT));
 */
                int modelColumn = table.convertColumnIndexToModel(column);
                columnHeaderLabel.setIcon(new VerticalTextIconWithArrow(
                        getHeaderRendererIcon(
                                modelColumn,
                                columnHeaderLabel.getFont().getSize()),
                        columnHeaderLabel,
                        columnHeaderLabel.getText(),
                        VerticalTextIcon.ROTATE_LEFT));

                columnHeaderLabel.setText("");
                columnHeaderLabel.setVerticalAlignment(JLabel.BOTTOM);
            }
            return columnHeaderComponent;
        }
    }
}
