/*
 *  Copyright (c) 2011 Joana P. Gonçalves.
 * 
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 * 
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package biggests.utils;

import java.io.File;
import javax.swing.filechooser.FileFilter;

/**
 * <p>Title: </p>
 *
 * <p>Description: </p>
 *
 * @author Joana P. Gonçalves
 */
public class FileFilterDirectoryChooser extends FileFilter {
    private String[] invalidDirectoryPaths;

    public FileFilterDirectoryChooser(String[] invalidDirectoryPaths) {
        this.invalidDirectoryPaths = invalidDirectoryPaths;
    }

    /**
     * Checks if a certain file is acceptable under the filter conditions.
     * Returns <code>true</code> if <code>file</code> is accepted, or
     * <code>false</code> otherwise.
     *
     * @param file the <code>File</code> to check
     * @return a <code>boolean</code> which is <code>true</code> if the file
     *         is accepted or <code>false</code> otherwise
     */
    public boolean accept(File file) {
        if (file.isFile()) return false;
        if (invalidDirectoryPaths == null) return true;

        String filePath = file.getAbsolutePath();
        for (String invalidDirectoryPath : invalidDirectoryPaths) {
            if (filePath.contains(invalidDirectoryPath)) {
                return false;
            }
        }
        return true;
    }

    /**
     * Returns the description of this file filter.
     *
     * @return the <code>String</code> description of this file filter
     */
    public String getDescription() {
        return ("Select target directory.");
    }
}
